@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2005-2017  Craig Barratt
+#   Copyright (C) 2005-2018  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.1.2, released 30 Apr 2017.
+# Version 4.2.0, released 8 Apr 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -347,6 +347,7 @@ our %ConfigMenu = (
 	    {name => "PingMaxMsec"},
 	    
 	    {text => "CfgEdit_Title_Other"},
+	    {name => "ClientComment"},
 	    {name => "ClientTimeout"},
 	    {name => "MaxOldPerPCLogFiles"},
 	    {name => "CompressLevel"},
@@ -465,8 +466,11 @@ sub action
             foreach my $paramInfo ( @{$ConfigMenu{$m}{param}} ) {
                 my $param = $paramInfo->{name};
                 if ( defined($paramInfo->{text}) ) {
-                    $text = $n;
-                    $mask[$text] = 1;
+                    $mask[$n] = 1;
+		    if ( ref($paramInfo->{visible}) ne "CODE"
+			    || &{$paramInfo->{visible}}($newConf, $bpc) ) {
+			$text = $n;
+		    }
                 } else {
                     if ( $bpc->{Conf}{CgiUserConfigEdit}{$param}
                           || (defined($bpc->{Conf}{CgiUserConfigEdit}{$param})
@@ -923,18 +927,11 @@ EOF
             # Just switching menus: copy all the orig_zZ_ input parameters
             #
             foreach my $var ( sort(keys(%In)) ) {
-                if ( $var =~ /^orig_zZ_/ ) {
+                if ( $var =~ /^orig_(zZ_|flds_)/ ) {
                     my $val = decode_utf8($In{$var});
                     $contentHidden .= <<EOF;
 <input type="hidden" name="$var" value="${EscHTML($val)}">
 EOF
-                } elsif ( $var =~ /^orig_flds_/ ) {
-                    foreach my $v ( split(/\0/, $In{$var}) ) {
-                        my $val = decode_utf8($v);
-                        $contentHidden .= <<EOF;
-<input type="hidden" name="$var" value="${EscHTML($val)}">
-EOF
-                    }
                 }
             }
 	}
@@ -1007,7 +1004,7 @@ sub fieldHiddenBuild
                 # rather than hard-coded
                 #
                 $content .= <<EOF;
-<input type="hidden" name="${prefix}_flds_$varName" value="${EscHTML($fld)}">
+<input type="hidden" name="${prefix}_flds_${varName}_zZ_$fldNum" value="${EscHTML($fld)}">
 EOF
             }
             $content .= fieldHiddenBuild($childType, "${varName}_zZ_$fldNum",
@@ -1197,7 +1194,7 @@ EOF
             if ( !$type->{noKeyEdit}
 		    && (keys(%$varValue) > 1 || $type->{emptyOk}) ) {
                 $content .= <<EOF;
-<input type="submit" name="del_${varName}_zZ_$fld" value="${EscHTML($Lang->{CfgEdit_Button_Delete})}"
+<input type="button" name="del_${varName}_zZ_$fld" value="${EscHTML($Lang->{CfgEdit_Button_Delete})}"
         onClick="deleteSubmit('${varName}_zZ_$fld')">
 EOF
             }
@@ -1210,7 +1207,7 @@ EOF
                 # rather than hard-coded
                 #
                 $content .= <<EOF;
-<input type="hidden" name="v_flds_$varName" value="${EscHTML($fld)}">
+<input type="hidden" name="v_flds_${varName}_zZ_$fldNum" value="${EscHTML($fld)}">
 EOF
             }
             $content .= "</td>\n";
@@ -1255,7 +1252,7 @@ EOF
                 # rather than hard-coded
                 #
                 $content .= <<EOF;
-<input type="hidden" name="v_flds_$varName" value="${EscHTML($fld)}">
+<input type="hidden" name="v_flds_${varName}_zZ_$fldNum" value="${EscHTML($fld)}">
 EOF
             }
             $content .= fieldEditBuild($childType, "${varName}_zZ_$fldNum",
@@ -1362,7 +1359,10 @@ sub fieldErrorCheck
         } elsif ( defined($type->{child}) ) {
             @order = sort(keys(%{$type->{child}}));
         } else {
-            @order = split(/\0/, $In{"v_flds_$varName"});
+            for ( my $fldNum = 0 ; ; $fldNum++ ) {
+                last if ( !defined($In{"v_flds_${varName}_zZ_$fldNum"}) );
+                push(@order, $In{"v_flds_${varName}_zZ_$fldNum"});
+            }
         }
         for ( my $fldNum = 0 ; $fldNum < @order ; $fldNum++ ) {
             my $fld = $order[$fldNum];
@@ -1475,7 +1475,10 @@ sub fieldInputParse
         } elsif ( defined($type->{child}) ) {
             @order = sort(keys(%{$type->{child}}));
         } else {
-            @order = split(/\0/, $In{"v_flds_$varName"});
+            for ( my $fldNum = 0 ; ; $fldNum++ ) {
+                last if ( !defined($In{"v_flds_${varName}_zZ_$fldNum"}) );
+                push(@order, $In{"v_flds_${varName}_zZ_$fldNum"});
+            }
         }
 
         for ( my $fldNum = 0 ; $fldNum < @order ; $fldNum++ ) {
