@@ -163,6 +163,7 @@ There are \$hostCntGood hosts that have been backed up, for a total of:
 <table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> User </td>
+    <td align="center"> Comment </td>
     <td align="center"> #Full </td>
     <td align="center"> Full Age (days) </td>
     <td align="center"> Full Size (GiB) </td>
@@ -175,7 +176,6 @@ There are \$hostCntGood hosts that have been backed up, for a total of:
     <td align="center"> Last attempt </td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Hosts with no Backups")}
 <p>
 There are \$hostCntNone hosts with no backups.
@@ -310,6 +310,7 @@ EOF
 
 # --------------------------------
 $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Backup Requested on \$host";
+$Lang{BackupPC__Delete_Requested_for_a_backup_of__host} = "BackupPC: Delete Requested for a backup of \$host";
 # --------------------------------
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
@@ -372,7 +373,6 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Queue Summary";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Backup Queue Summary")}
-<br><br>
 \${h2("User Queue Summary")}
 <p>
 The following user requests are currently queued:
@@ -383,7 +383,6 @@ The following user requests are currently queued:
     <td> User </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("Background Queue Summary")}
 <p>
@@ -395,7 +394,6 @@ The following background requests are currently queued:
     <td> User </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("Command Queue Summary")}
 <p>
 The following command requests are currently queued:
@@ -649,6 +647,34 @@ Reply from server was: \$reply
 EOF
 
 
+# --------------------------------
+$Lang{BackupPC__Delete_Backup_Confirm__num_of__host} = "BackupPC: Delete Backup Confirm #\$num of \$host";
+# --------------------------------
+$Lang{A_filled} = "a filled";
+$Lang{An_unfilled} = "an unfilled";
+$Lang{Are_you_sure_delete} = <<EOF;
+\${h1("Are you sure?")}
+<p>
+You are about to delete \$filled \$type backup #\$num of \$host.
+
+<form name="Confirm" action="\$MyURL" method="get">
+
+<input type="hidden" name="host" value="\${EscHTML(\$host)}">
+<input type="hidden" name="num" value="\$num">
+
+<input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
+
+Do you really want to do this?
+
+<input type="button" value="\${EscHTML(\$Lang->{CfgEdit_Button_Delete})}"
+ onClick="document.Confirm.action.value='deleteBackup';
+          document.Confirm.submit();">
+
+<input type="submit" value="No" name="ignore">
+</form>
+EOF
+
 # -------------------------
 $Lang{Host__host_Backup_Summary} = "BackupPC: Host \$host Backup Summary";
 
@@ -686,6 +712,7 @@ Click on the backup number to browse and restore backup files.
     <td align="center"> Start Date </td>
     <td align="center"> Duration/mins </td>
     <td align="center"> Age/days </td>
+    <td align="center"> </td>
     <td align="center"> Server Backup Path </td>
 </tr>
 \$str
@@ -694,9 +721,7 @@ Click on the backup number to browse and restore backup files.
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Xfer Error Summary")}
-<br><br>
 <table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Type </td>
@@ -708,7 +733,6 @@ Click on the backup number to browse and restore backup files.
 </tr>
 \$errStr
 </table>
-<br><br>
 
 \${h2("File Size/Count Reuse Summary")}
 <p>
@@ -735,7 +759,6 @@ Empty files and SMB errors aren\'t counted in the reuse and new counts.
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Compression Summary")}
 <p>
@@ -759,7 +782,6 @@ compressed files.
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archive Summary";
@@ -899,7 +921,7 @@ the backups:
 <li> Click on a file version link (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) to download that file,
 <li> Files with the same contents between different backups have the same
-     version number,
+     version number (except between v3 and v4 backups),
 <li> Files or directories not present in a particular backup have an
      empty box.
 <li> Files shown with the same version might have different attributes.
@@ -1003,6 +1025,8 @@ $Lang{Only_privileged_users_can_view_log_files} = "Only privileged users can vie
 $Lang{Only_privileged_users_can_view_email_summaries} = "Only privileged users can view email summaries.";
 $Lang{Only_privileged_users_can_browse_backup_files} = "Only privileged users can browse backup files"
                 . " for host \${EscHTML(\$In{host})}.";
+$Lang{Only_privileged_users_can_delete_backups} = "Only privileged users can delete backups"
+                . " of host \${EscHTML(\$host)}.";
 $Lang{Empty_host_name} = "Empty host name.";
 $Lang{Directory___EscHTML} = "Directory \${EscHTML(\"\$TopDir/pc/\$host/\$num\")}"
 		    . " is empty";
@@ -1053,6 +1077,8 @@ $Lang{Backup_requested_on__host_by__User} = "Backup requested on \$host by \$Use
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Backup stopped/dequeued on \$host by \$User";
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restore requested to host \$hostDest, backup #\$num,"
 	     . " by \$User from \$ENV{REMOTE_ADDR}";
+$Lang{Delete_requested_for_backup_of__host_by__User} = "Delete requested for backup #\$num of \$host"
+             . " by \$User from \$ENV{REMOTE_ADDR}";
 $Lang{Archive_requested} = "Archive requested by \$User from \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
