@@ -13,7 +13,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2002-2017  Craig Barratt
+#   Copyright (C) 2002-2018  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #
 #========================================================================
 #
-# Version 4.1.2, released 30 Apr 2017.
+# Version 4.2.0, released 8 Apr 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -166,6 +166,7 @@ sub start
                             host      => $t->{host},
                             hostIP    => $t->{hostIP},
                             client    => $t->{client},
+			    shareName => $t->{shareName},
                             confDir   => $conf->{ConfDir},
                             sshPath   => $conf->{SshPath},
                         });
@@ -357,6 +358,7 @@ sub start
                             host      => $t->{host},
                             hostIP    => $t->{hostIP},
                             client    => $t->{client},
+			    shareName => $t->{shareName},
                             confDir   => $conf->{ConfDir},
                             sshPath   => $conf->{SshPath},
                         });
@@ -576,7 +578,7 @@ sub run
                 $t->{XferLOG}->write(\"Parsing done: nFilesTotal = $t->{stats}{nFilesTotal}\n")
                                         if ( $conf->{XferLogLevel} >= 3 );
                 $t->{fileCnt} = $t->{stats}{nFilesTotal};
-                $t->{byteCnt} = $t->{stats}{nFilesTotal};
+                $t->{byteCnt} = $t->{stats}{sizeTotal};
                 next;
             }
 
@@ -603,12 +605,19 @@ sub run
     #
     # Remove any rsyncTmp files in the backup directory
     #
-    my $bkupDir = "$conf->{TopDir}/pc/$t->{client}/$t->{backups}[$t->{newBkupIdx}]{num}";
-    foreach my $e ( @{BackupPC::DirOps::dirRead($bpc, $bkupDir)} ) {
-	if ( $e->{name} =~ /^rsyncTmp\.\d+\.[.\d]+$/ ) {
-            $t->{XferLOG}->write(\"Removing rsync temporary file $bkupDir/$e->{name}\n");
+    my $bkupDir = $t->{type} eq "restore" ? "$conf->{TopDir}/pc/$t->{bkupSrcHost}/$t->{bkupSrcNum}"
+					  : "$conf->{TopDir}/pc/$t->{client}/$t->{backups}[$t->{newBkupIdx}]{num}";
+    my $bkupDirEntries = BackupPC::DirOps::dirRead($bpc, $bkupDir);
+    my $pidRunning = {};
+    if ( ref($bkupDirEntries) eq 'ARRAY' ) {
+        foreach my $e ( @$bkupDirEntries ) {
+            next if ( $e->{name} !~ /^rsyncTmp\.(\d+)\.\d+\.\d+$/ );
+            my $pid = $1;
+            $pidRunning->{$pid} = kill(0, $pid) ? 1 : 0 if ( !defined($pidRunning->{$pid} ) );
+            next if ( $pidRunning->{$pid} );
+	    $t->{XferLOG}->write(\"Removing rsync temporary file $bkupDir/$e->{name}\n");
 	    unlink("$bkupDir/$e->{name}");
-	}
+        }
     }
 
     if ( $t->{type} eq "restore" ) {
